# pysdic

## Description

Python Stereo Digital Image Correlation Toolbox.

All input arrays are automatically converted to `numpy.float64` so that every calculation is performed in double‑precision, guaranteeing numerical stability throughout the library.

## Authors

- Artezaru <artezaru.github@proton.me>

- **Git Plateform**: https://github.com/Artezaru/pysdic.git
- **Online Documentation**: https://Artezaru.github.io/pysdic

## Installation

Install with pip

```
pip install pysdic
```

```
pip install git+https://github.com/Artezaru/pysdic.git
```

Clone with git

```
git clone https://github.com/Artezaru/pysdic.git
```

## License

Copyright 2025 Artezaru

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.



